#!/bin/bash -f
#
SCRIPTHOME="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"
SCRIPTHOME=$PWD

unset FTP_PROXY
unset ALL_PROXY
unset HTTPS_PROXY
unset HTTP_PROXY
export NO_PROXY=localhost

# ulimit -Sc unlimited

ARGS=$*
SHMLOG=""
APP="t1"
KVER=3.2

export SHELL=/bin/bash
export SHM=1
export QPRELOAD=/export/home/kdb/lib/libhugetlbfs.so
ENVF=/export/home/kdb/ENV
if [ -e $ENVF ] && [ -s $ENVF ] ; then
  source $ENVF
fi

args=$(getopt -l "kver,shmlog,start" -o "k:v" -- "$@")

while [ $# -ge 1 ]; do
    case "$1" in
        --)
            # No more options left.
            shift
            break
            ;;
         -k|--kver)
            KVER="$2"
            shift
            ;;
        --shmlog)
            SHMLOG="1"
            shift
            ;;
        --start)
            OP="start"
            shift
            ;;
    esac
    shift
done

if [ -z "$APP" ] || [ "$OP" == "" ] ; then
    echo "Bad/missing arguments: $0 $ARGS"
    echo "Missing one of: OP '$OP' or -A '$APP'" 
    echo "Usage: $0 -A appname [-P startport]"
    exit -1
fi

THIRD_PARTY=/export/home/kdb/thirdparty
export RLWRAP="/export/home/kdb/bin/rlwrap -H /dev/null"
export QLIC="$THIRD_PARTY/kx/licenses/licenses2014/generic"
export QHOME="$THIRD_PARTY/kx/$KVER"

export PATH="/export/home/kdb/bin:$QHOME/l64:/sbin:/usr/sbin:/bin:/usr/bin:$THIRD_PARTY/tibrv/tibrv_8.0/bin"
# export PATH="/export/home/kdb/bin:$QHOME/l64:/sbin:/usr/sbin:/bin:/usr/bin:/dat/tibrv/linux/8.0/bin"

export LD_LIBRARY_PATH="$QHOME/l64:$THIRD_PARTY/odbc/lib:/apps/kdb/local/lib:/usr/lib64:$THIRD_PARTY/mama/mama_4.0.8e/lib:$THIRD_PARTY/tibrv/tibrv_8.0/lib"

export FREETDSCONF=/export/home/kdb/env/freetds.conf

APP_HOME="$SCRIPTHOME"/$APP
cd $APP_HOME

startshm () {
    SHMSERVER=/export/home/kdb/bin/shmserver
    if [ $SHM == 1 ] ; then
        S="screen -d -m -t shmserver -S shmserver -L -c scripts/shmrc $RLWRAP -c $SHMSERVER $SHMLOG"
        echo "Starting shmserver: $S"
        $(LD_PRELOAD=$QPRELOAD $S)
        sleep 5s
    fi
}

dostart () {
    TEST=`curl --noproxy '*' -s http://localhost:$PORT`
    [[ $TEST ]] && echo "$APP already running on $PORT!"
    [[ $TEST ]] && exit -1
    startshm
}

doit () {
    case "$1" in 
    start)
        dostart
        ;;
    esac
}

doit $OP

